@@ -41,7 +41,9 @@
 #include <net/if.h>
 #include <netinet/in.h>
 #include <sys/ioctl.h>
-#include <sys/ptrace.h>
+#if 0
+#  include <sys/ptrace.h>
+#endif
 #include <sys/socket.h>
 #include <sys/time.h>
 #include <sys/utsname.h>
@@ -561,7 +563,9 @@ soup_address_new_cb (GIOChannel* iochannel,
 		/* Cleanup state */
 		g_source_remove (state->watch);
 		close (state->fd);
-		waitpid (state->pid, NULL, WNOHANG);
+
+		/* FIXME: Wait for HUP signal before doing this */
+		waitpid (state->pid, NULL, 0);
 	}
 
 	/* Get state data before realloc */
@@ -783,6 +787,10 @@ soup_address_new (const gchar* name,
 
 		signal (SIGCHLD, SIG_IGN);
 
+#if 0
+		/* 
+		 * This will send the parent process a SIGSTOP.
+		 */
 		if (ptrace (PTRACE_ATTACH, getppid (), NULL, NULL) == -1) {
 			/* 
 			 * Attach failed; it's probably already being
@@ -796,15 +804,16 @@ soup_address_new (const gchar* name,
 		}
 		
 		/* 
-		 * We just SIGSTOPped it; we need to CONT it now. 
+		 * Wait for the parent to actually STOP.
 		 */
-		waitpid (getppid (), NULL, 0);
+		waitpid (getppid (), NULL, WUNTRACED);
 
 		if (ptrace (PTRACE_DETACH, getppid (), NULL, NULL) == -1)
 			g_warning ("ptrace: Detach failed: %s", 
 				   strerror(errno));
 
 		kill (getppid(), SIGCONT);
+#endif
 
 		/* 
 		 * Try to get the host by name (ie, DNS) 
